import os
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

STR_DEFAULT_RESPONSE = "Sorry, I could not process that."
STR_KEYWORDS = "KEYWORDS"


STR_DEFAULT_NEURONS_PATH = BASE_DIR + "/data/neurons"
